@@ -5,7 +5,7 @@ using SparseConnectivityTracer
 using SparseConnectivityTracerBenchmarks.ODE: Brusselator!
 using Test
 
-# Load definitions of GRADIENT_TRACERS, GRADIENT_PATTERNS, HESSIAN_TRACERS and HESSIAN_PATTERNS
+# Load definitions of GRADIENT_TRACERS and HESSIAN_TRACERS
 include("tracers_definitions.jl")
 
 function test_brusselator(detector::AbstractSparsityDetector)
@@ -19,7 +19,7 @@ function test_brusselator(detector::AbstractSparsityDetector)
 end
 
 @testset "$T" for T in GRADIENT_TRACERS
-    detector = TracerSparsityDetector(; gradient_tracer_type = T)
+    detector = TracerSparsityDetector(T)
     test_brusselator(detector)
     yield()
 end
