@@ -3,7 +3,6 @@ using SparseConnectivityTracer
 using SparseConnectivityTracer:
     GradientTracer,
     Dual,
-    IndexSetGradientPattern,
     isemptytracer,
     MissingPrimalError,
     split_dual_array,
@@ -17,13 +16,12 @@ using LinearAlgebra: inv, pinv, dot
 using SparseArrays: sparse, spdiagm
 
 S = BitSet
-P = IndexSetGradientPattern{Int, S}
-TG = GradientTracer{P}
+TG = GradientTracer{eltype(S), S}
 
 # Utilities for quick testing
 idx2set(is) = S(is)
 idx2set(r::AbstractRange) = idx2set(collect(r))
-idx2tracer(is) = TG(P(idx2set(is)))
+idx2tracer(is) = TG(idx2set(is))
 
 function sameidx(s1::AbstractSet, s2::AbstractSet)
     same = s1 == s2
@@ -205,7 +203,10 @@ arrayname(A) = "$(typeof(A)) $(size(A))"
         testJ1(opnorm1, A)
         testH0(opnorm1, A)
     end
-    @testset "opnorm(A, 2) $(arrayname(A))" for A in ALL_MATRICES
+    @testset "opnorm(A, 2) $(arrayname(A))" for A in NONDIAG_MATRICES
+        # On diagonal matrices, opnorm(A, 2) returns the highest diagonal entry
+        # since the spectral norm is equal to the largest singular value of A.
+        # For diagonal matrices, the Hessian pattern is therefore "empty".
         testJ1(opnorm2, A)
         testH1(opnorm2, A)
     end
